module Debate.Arguments.Medicine.ApoBCVD exposing (..)

import Debate.Types exposing (..)


argumentApoBCVD : Argument
argumentApoBCVD =
    let
        argumentNotation : ArgumentStructure
        argumentNotation =
            { notationP1 = "∀x(Px↔Qx)"
            , notationP2 = "Qw"
            , notationP3 = ""
            , notationP4 = ""
            , notationP5 = ""
            , notationP6 = ""
            , notationP7 = ""
            , notationP8 = ""
            , notationP9 = ""
            , notationP10 = ""
            , notationC = "Pw"
            }
    in
    { argumentTitle = "Argument for Atherogenic ApoB"
    , propositionTitle = "ApoB-containing lipoproteins dose-dependently cause atherosclerosis."
    , propositionReductio = ""
    , propositionSummary = "ApoB-containing lipoproteins consistently and proportionately associate with increased plaque volume after controlling for relevant confounders, which satisfies the conditions outlined for an exposure to cause atherosclerosis."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qw)|=(Pw)"
    , proofText =
        argumentNotation.notationP1
            ++ ", "
            ++ argumentNotation.notationP2
            ++ ", ∴ "
            ++ argumentNotation.notationC
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) dose-dependently causes atherosclerosis"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) consistently, linearly, and proportionately associates with increased plaque volume after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "a substance"
          }
        , { definiendum = "w"
          , definiens = "ApoB-containing lipoproteins"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, a substance dose-dependently causes atherosclerosis if, and only if, a substance consistently, linearly, and proportionately associates with increased plaque volume after adjustment or control over relevant confounders and covariates."
                  , notation = argumentNotation.notationP1
                  }
                , { premise = "ApoB-containing lipoproteins consistently, linearly, and proportionately associates with increased plaque volume after adjustment or control over relevant confounders and covariates."
                  , notation = argumentNotation.notationP2
                  }
                ]
          , conclusion = "Therefore, ApoB-containing lipoproteins dose-dependently cause atherosclerosis."
          , conclusionNotation = argumentNotation.notationC
          }
        ]
    }
