module Debate.Arguments.Philosophy.EfilismPatrolSquad exposing (..)

import Debate.Types exposing (..)


argumentEfilismPatrolSquad : Argument
argumentEfilismPatrolSquad =
    let
        argumentNotation : ArgumentStructure
        argumentNotation =
            { notationP1 = "P→Q"
            , notationP2 = "¬Q"
            , notationP3 = "¬P∧R→¬S"
            , notationP4 = "R"
            , notationP5 = "¬S→W"
            , notationP6 = ""
            , notationP7 = ""
            , notationP8 = ""
            , notationP9 = ""
            , notationP10 = ""
            , notationC = "W"
            }
    in
    { argumentTitle = "The Eternal Intergalactic Sentience Patrol Squad"
    , propositionTitle = "Efilists are committed to pragmatic natalism."
    , propositionReductio = "Efilists fundamentally believe that sentient life is inherently characterized by suffering and that the most ethical action is to prevent the creation of any new sentient beings, ultimately aiming to completely eliminate all conscious life in the universe to end suffering permanently."
    , propositionSummary = "If efilists follow their own logic to its ultimate conclusion, they would paradoxically be committed to a form of pragmatic natalism - the very opposite of their core philosophical stance."
    , proofLink = "https://www.umsu.de/trees/#(P~5Q),(~3Q),(~3P~1R~5~3S),(R),(~3S~5W)|=(W)"
    , proofText =
        argumentNotation.notationP1
            ++ ", "
            ++ argumentNotation.notationP2
            ++ ", "
            ++ argumentNotation.notationP3
            ++ ", "
            ++ argumentNotation.notationP4
            ++ ", "
            ++ argumentNotation.notationP5
            ++ ", ∴ "
            ++ argumentNotation.notationC
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "humans abstaining from procreation maximally reduces rights violations"
          }
        , { definiendum = "Q"
          , definiens = "humans have sterilized all sentient life in the universe"
          }
        , { definiendum = "R"
          , definiens = "many more generations are required to sterilize all sentient life in the universe"
          }
        , { definiendum = "S"
          , definiens = "efilists should abstain from procreation until all sentient life in the universe is sterilized"
          }
        , { definiendum = "W"
          , definiens = "efilists are committed to pragmatic natalism"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If humans abstaining from procreation maximally reduces rights violations, then humans have sterilized all sentient life in the universe."
                  , notation = argumentNotation.notationP1
                  }
                , { premise = "Humans have not sterilized all sentient life in the universe."
                  , notation = argumentNotation.notationP2
                  }
                , { premise = "If humans abstaining from procreation does not maximally reduce rights violations and many more generations are required to sterilize all sentient life in the universe, then efilists should not abstain from procreation until all sentient life in the universe is sterilized."
                  , notation = argumentNotation.notationP3
                  }
                , { premise = "Many more generations are required to sterilize all sentient life in the universe."
                  , notation = argumentNotation.notationP4
                  }
                , { premise = "If efilists should not abstain from procreation until all sentient life in the universe is sterilized, then efilists are committed to pragmatic natalism."
                  , notation = argumentNotation.notationP5
                  }
                ]
          , conclusion = "Therefore, efilists are committed to pragmatic natalism."
          , conclusionNotation = argumentNotation.notationC
          }
        ]
    }
